from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import String, File, Int, Boolean

Siriusadapter_V0_1_0 = CommandToolBuilder(tool="SiriusAdapter", base_command=["SiriusAdapter"], inputs=[ToolInput(tag="in_executable", input_type=String(optional=True), prefix="-executable", doc=InputDocumentation(doc="Sirius executable e.g. sirius")), ToolInput(tag="in_in", input_type=File(optional=True), prefix="-in", doc=InputDocumentation(doc="*                            MzML Input file (valid formats: 'mzml')")), ToolInput(tag="in_in_feature_info", input_type=File(optional=True), prefix="-in_featureinfo", doc=InputDocumentation(doc="FeatureXML input with feature and adduct information (valid formats: 'featurexml')")), ToolInput(tag="in_out_sirius", input_type=File(optional=True), prefix="-out_sirius", doc=InputDocumentation(doc="*                    MzTab Output file for SiriusAdapter results (valid formats: 'mzTab')")), ToolInput(tag="in_out_finger_id", input_type=File(optional=True), prefix="-out_fingerid", doc=InputDocumentation(doc="MzTab output file for CSI:FingerID, if this parameter is given, SIRIUS will search for a molecular structure using CSI:FingerID after determining the sum formula (valid formats: 'mzTab')")), ToolInput(tag="in_filter_by_num_mass_traces", input_type=Int(optional=True), prefix="-filter_by_num_masstraces", doc=InputDocumentation(doc="Features have to have at least x MassTraces. To use this parameter feature_only is neccessary (default: '1' min: '1')")), ToolInput(tag="in_feature_only", input_type=Boolean(optional=True), prefix="-feature_only", doc=InputDocumentation(doc="Uses the feature information from in_featureinfo to reduce the search space to only MS2 associated with a feature")), ToolInput(tag="in_precursor_mz_tolerance", input_type=Int(optional=True), prefix="-precursor_mz_tolerance", doc=InputDocumentation(doc="Tolerance window for precursor selection (Feature selection in regard to the precursor) (default: '0.005')")), ToolInput(tag="in_precursor_mz_tolerance_unit", input_type=String(optional=True), prefix="-precursor_mz_tolerance_unit", doc=InputDocumentation(doc="Unit of the precursor_mz_tolerance (default: 'Da' valid: 'Da', 'ppm')")), ToolInput(tag="in_precursor_rt_tolerance", input_type=Int(optional=True), prefix="-precursor_rt_tolerance", doc=InputDocumentation(doc="Tolerance window (left and right) for precursor selection [seconds] (default: '5')")), ToolInput(tag="in_profile", input_type=String(optional=True), prefix="-profile", doc=InputDocumentation(doc="Specify the used analysis profile (default: 'qtof' valid: 'qtof', 'orbitrap', 'fticr')")), ToolInput(tag="in_candidates", input_type=Int(optional=True), prefix="-candidates", doc=InputDocumentation(doc="The number of candidates in the SIRIUS output. (default: '5')")), ToolInput(tag="in_database", input_type=String(optional=True), prefix="-database", doc=InputDocumentation(doc="Search formulas in given database (default: 'all' valid: 'all', 'chebi', 'custom', 'kegg', 'bio', 'natural products', 'pubmed', 'hmdb', 'biocyc', 'hsdb', 'knapsack', 'biological', 'zinc bio', 'gnps', 'pubchem', 'mesh', 'maconda')")), ToolInput(tag="in_noise", input_type=Int(optional=True), prefix="-noise", doc=InputDocumentation(doc="Median intensity of noise peaks (default: '0')")), ToolInput(tag="in_ppm_max", input_type=Int(optional=True), prefix="-ppm_max", doc=InputDocumentation(doc="Allowed ppm for decomposing masses (default: '10')")), ToolInput(tag="in_isotope", input_type=String(optional=True), prefix="-isotope", doc=InputDocumentation(doc="How to handle isotope pattern data. Use 'score' to use them for ranking or 'filter' if you just want to remove candidates with bad isotope pattern. With 'both' you can use isotopes for filtering and scoring. Use 'omit' to ignore isotope pattern. (default: 'both' valid: 'score', 'filter', 'both', 'omit')")), ToolInput(tag="in_elements", input_type=Int(optional=True), prefix="-elements", doc=InputDocumentation(doc="The allowed elements. Write CHNOPSCl to allow the elements C, H, N, O, P, S and Cl. Add numbers in brackets to restrict the maximal allowed occurrence of these elements: CHNOP[5]S[8]Cl[1]. (default: 'CHNOP[5]S[8]Cl[1]')")), ToolInput(tag="in_compound_timeout", input_type=Int(optional=True), prefix="-compound_timeout", doc=InputDocumentation(doc="Time out in seconds per compound. To disable the timeout set the value to 0 (default: '10')")), ToolInput(tag="in_tree_timeout", input_type=Int(optional=True), prefix="-tree_timeout", doc=InputDocumentation(doc="Time out in seconds per fragmentation tree computation. (default: '0')")), ToolInput(tag="in_top_n_hits", input_type=Int(optional=True), prefix="-top_n_hits", doc=InputDocumentation(doc="The number of top hits for each compound written to the CSI:FingerID output (default: '10')")), ToolInput(tag="in_auto_charge", input_type=Boolean(optional=True), prefix="-auto_charge", doc=InputDocumentation(doc="Use this option if the charge of your compounds is unknown and you do not want to assume [M+H]+ as default. With the auto charge option SIRIUS will not care about charges and allow arbitrary adducts for the precursor peak.")), ToolInput(tag="in_ion_tree", input_type=Boolean(optional=True), prefix="-ion_tree", doc=InputDocumentation(doc="Print molecular formulas and node labels with the ion formula instead of the neutral formula")), ToolInput(tag="in_no_recalibration", input_type=Boolean(optional=True), prefix="-no_recalibration", doc=InputDocumentation(doc="If this option is set, SIRIUS will not recalibrate the spectrum during the analysis.")), ToolInput(tag="in_most_intense_ms_two", input_type=Boolean(optional=True), prefix="-most_intense_ms2", doc=InputDocumentation(doc="SIRIUS uses the fragmentation spectrum with the most intense precursor peak (for each spectrum)")), ToolInput(tag="in_ini", input_type=File(optional=True), prefix="-ini", doc=InputDocumentation(doc="Use the given TOPP INI file")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="-threads", doc=InputDocumentation(doc="Sets the number of threads allowed to be used by the TOPP tool (default: '1')")), ToolInput(tag="in_write_ini", input_type=File(optional=True), prefix="-write_ini", doc=InputDocumentation(doc="Writes the default configuration file")), ToolInput(tag="in_helphelp", input_type=Boolean(optional=True), prefix="--helphelp", doc=InputDocumentation(doc="Shows all options (including advanced)"))], outputs=[ToolOutput(tag="out_out_sirius", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_sirius", type_hint=File()), doc=OutputDocumentation(doc="*                    MzTab Output file for SiriusAdapter results (valid formats: 'mzTab')")), ToolOutput(tag="out_out_finger_id", output_type=File(optional=True), selector=InputSelector(input_to_select="in_out_finger_id", type_hint=File()), doc=OutputDocumentation(doc="MzTab output file for CSI:FingerID, if this parameter is given, SIRIUS will search for a molecular structure using CSI:FingerID after determining the sum formula (valid formats: 'mzTab')"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Siriusadapter_V0_1_0().translate("wdl", allow_empty_container=True)

